@@ -12,7 +12,7 @@ class APIClient:
             text = r.text
             if "Invalid API key!" in text:
                 raise Exception("Invalid API key!")
-            elif "Please, use POST not GET":
+            elif "Please, use POST not GET" in text:
                 raise Exception("Please, use POST not GET. [LIB ERROR, CONTACT DEVELOPER]")
 
             f = open(filename, "wb")
